16.122. cdist-type__ping(7) — cdist 6.9.8 documentation

# 16.122. cdist-type__ping(7)

## 16.122.1. NAME

cdist-type__ping - Try to connect to host and return 'pong' on success

## 16.122.2. DESCRIPTION

A simple type which tries to connect to a remote host and runs a simple command to ensure everything is working.

## 16.122.3. REQUIRED PARAMETERS

None.

## 16.122.4. OPTIONAL PARAMETERS

None.

## 16.122.5. EXAMPLES

    __ping

## 16.122.6. AUTHORS

Olliver Schinagl <oliver--@--schinagl.nl>

## 16.122.7. COPYING

Copyright (C) 2018 Schinagl. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.